@@ -1,23 +1,23 @@
-/* $Id: sm_if.c,v 1.2 2004/08/07 14:48:35 dijkstra Exp $ */
+/* $Id: sm_if.c,v 1.3 2005/10/18 19:58:12 dijkstra Exp $ */
 
 #include <stdlib.h>
 
+#include "sylimits.h"
+#include "data.h"
 #include "error.h"
 
 void
-init_if(char *s)
+init_if(struct stream *st)
 {
     fatal("if module not available");
 }
-
 void
 gets_if()
 {
     fatal("if module not available");
 }
-
 int
-get_if(char *symon_buf, int maxlen, char *s)
+get_if(char *symon_buf, int maxlen, struct stream *st)
 {
     fatal("if module not available");
 
