@@ -1,17 +1,19 @@
-/* $Id: sm_mbuf.c,v 1.1 2004/08/07 12:21:36 dijkstra Exp $ */
+/* $Id: sm_mbuf.c,v 1.2 2005/10/18 19:58:12 dijkstra Exp $ */
 
 #include <stdlib.h>
 
+#include "sylimits.h"
+#include "data.h"
 #include "error.h"
 
 void
-init_mbuf(char *s)
+init_mbuf(struct stream *st)
 {
     fatal("mbuf module not available");
 }
 
 int
-get_mbuf(char *symon_buf, int maxlen, char *s)
+get_mbuf(char *symon_buf, int maxlen, struct stream *st)
 {
     fatal("mbuf module not available");
 
