@@ -1,11 +1,13 @@
-/* $Id: sm_proc.c,v 1.1 2004/08/07 12:21:36 dijkstra Exp $ */
+/* $Id: sm_proc.c,v 1.3 2005/10/19 20:06:07 dijkstra Exp $ */
 
 #include <stdlib.h>
 
+#include "sylimits.h"
+#include "data.h"
 #include "error.h"
 
 void
-init_proc(char *s)
+init_proc(struct stream *st)
 {
     fatal("proc module not available");
 }
@@ -16,8 +18,14 @@ gets_proc()
     fatal("proc module not available");
 }
 
+void
+privinit_proc()
+{
+    fatal("proc module not available");
+}
+
 int
-get_proc(char *symon_buf, int maxlen, char *s)
+get_proc(char *symon_buf, int maxlen, struct stream *st)
 {
     fatal("proc module not available");
 
