@@ -1,4 +1,4 @@
-/* $Id: symon.c,v 1.47 2007/04/20 18:53:27 dijkstra Exp $ */
+/* $Id: symon.c,v 1.50 2007/12/11 14:17:59 dijkstra Exp $ */
 
 /*
  * Copyright (c) 2001-2007 Willem Dijkstra
@@ -65,14 +65,15 @@ __END_DECLS
 
 int flag_unsecure = 0;
 int flag_hup = 0;
+int flag_testconf = 0;
 int symon_interval = SYMON_DEFAULT_INTERVAL;
 
 /* map stream types to inits and getters */
 struct funcmap streamfunc[] = {
     {MT_IO1, 0, NULL, init_io, gets_io, get_io},
     {MT_CPU, 0, NULL, init_cpu, gets_cpu, get_cpu},
-    {MT_MEM, 0, NULL, init_mem, gets_mem, get_mem},
-    {MT_IF, 0, NULL, init_if, gets_if, get_if},
+    {MT_MEM1, 0, NULL, init_mem, gets_mem, get_mem},
+    {MT_IF1, 0, NULL, init_if, gets_if, get_if},
     {MT_PF, 0, privinit_pf, init_pf, gets_pf, get_pf},
     {MT_DEBUG, 0, NULL, init_debug, NULL, get_debug},
     {MT_PROC, 0, privinit_proc, init_proc, gets_proc, get_proc},
@@ -81,6 +82,8 @@ struct funcmap streamfunc[] = {
     {MT_IO2, 0, NULL, init_io, gets_io, get_io},
     {MT_PFQ, 0, privinit_pfq, init_pfq, gets_pfq, get_pfq},
     {MT_DF, 0, NULL, init_df, gets_df, get_df},
+    {MT_MEM2, 0, NULL, init_mem, gets_mem, get_mem},
+    {MT_IF2, 0, NULL, init_if, gets_if, get_if},
     {MT_EOT, 0, NULL, NULL, NULL}
 };
 
@@ -187,7 +190,7 @@ main(int argc, char *argv[])
 
     cfgpath = SYMON_CONFIG_FILE;
 
-    while ((ch = getopt(argc, argv, "dvuf:")) != -1) {
+    while ((ch = getopt(argc, argv, "df:tuv")) != -1) {
         switch (ch) {
         case 'd':
             flag_debug = 1;
@@ -197,6 +200,10 @@ main(int argc, char *argv[])
             cfgpath = xstrdup(optarg);
             break;
 
+        case 't':
+            flag_testconf = 1;
+            break;
+
         case 'u':
             flag_unsecure = 1;
             break;
@@ -204,7 +211,7 @@ main(int argc, char *argv[])
         case 'v':
             info("symon version %s", SYMON_VERSION);
         default:
-            info("usage: %s [-d] [-u] [-v] [-f cfgfile]", __progname);
+            info("usage: %s [-d] [-t] [-u] [-v] [-f cfgfile]", __progname);
             exit(EX_USAGE);
         }
     }
@@ -212,6 +219,11 @@ main(int argc, char *argv[])
     if (!read_config_file(&mul, cfgpath))
         fatal("configuration file contained errors - aborting");
 
+    if (flag_testconf) {
+        info("%s: ok", cfgpath);
+        exit(EX_OK);
+    }
+
     set_stream_use(&mul);
 
     /* open resources that might not be available after privilege drop */
@@ -254,6 +266,7 @@ main(int argc, char *argv[])
 
     /* init modules */
     SLIST_FOREACH(mux, &mul, muxes) {
+        init_symon_packet(mux);
         connect2mux(mux);
         SLIST_FOREACH(stream, &mux->sl, streams) {
             (streamfunc[stream->type].init) (stream);
@@ -291,6 +304,7 @@ main(int argc, char *argv[])
 
                     /* init modules */
                     SLIST_FOREACH(mux, &mul, muxes) {
+                        init_symon_packet(mux);
                         connect2mux(mux);
                         SLIST_FOREACH(stream, &mux->sl, streams) {
                             (streamfunc[stream->type].init) (stream);
