@@ -1,7 +1,7 @@
-/* $Id: readconf.c,v 1.31 2007/02/11 20:07:32 dijkstra Exp $ */
+/* $Id: readconf.c,v 1.34 2007/12/11 14:17:59 dijkstra Exp $ */
 
 /*
- * Copyright (c) 2001-2005 Willem Dijkstra
+ * Copyright (c) 2001-2007 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -55,10 +55,12 @@ const char *default_symux_port = SYMUX_PORT;
 int
 insert_filename(char *path, int maxlen, int type, char *args)
 {
+    int i, result;
     char *ts;
     char *ta;
+    char *fta;
 
-    ts = ta = NULL;
+    fta = ts = ta = NULL;
 
     switch (type) {
     case MT_CPU:
@@ -69,19 +71,21 @@ insert_filename(char *path, int maxlen, int type, char *args)
         ts = "df_";
         ta = args;
         break;
-    case MT_IF:
+    case MT_IF1:  /* rrd stores 64bits, if1 and if2 are equivalent */
+    case MT_IF2:
         ts = "if_";
         ta = args;
         break;
-    case MT_IO2:
-        ts = "io_";
-        ta = args;
-        break;
     case MT_IO1:
         ts = "io1_";
         ta = args;
         break;
-    case MT_MEM:
+    case MT_IO2:
+        ts = "io_";
+        ta = args;
+        break;
+    case MT_MEM1: /* rrd stores 64bits, mem1 and mem2 are equivalent */
+    case MT_MEM2:
         ts = "mem";
         ta = "";
         break;
@@ -106,7 +110,7 @@ insert_filename(char *path, int maxlen, int type, char *args)
         ta = args;
         break;
     case MT_SENSOR:
-        ts = "sensor";
+        ts = "sensor_";
         ta = args;
         break;
     default:
@@ -115,11 +119,21 @@ insert_filename(char *path, int maxlen, int type, char *args)
         return 0;
     }
 
-    if ((snprintf(path, maxlen, "/%s%s.rrd", ts, ta)) >= maxlen) {
-        return 0;
-    } else {
-        return 1;
+    /* ensure that no '/' remain in args */
+    fta = xstrdup(ta);
+
+    for (i = 0; i < strlen(fta); i++) {
+        if (fta[i] == '/') fta[i] = '_';
     }
+
+    if ((snprintf(path, maxlen, "/%s%s.rrd", ts, fta)) >= maxlen) {
+        result = 0;
+    } else {
+        result = 1;
+    }
+
+    xfree(fta);
+    return result;
 }
 /* mux <host> (port|,| ) <number> */
 int
@@ -200,9 +214,11 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
                 case LXT_CPU:
                 case LXT_DF:
                 case LXT_IF:
+                case LXT_IF1:
                 case LXT_IO:
                 case LXT_IO1:
                 case LXT_MEM:
+                case LXT_MEM1:
                 case LXT_PF:
                 case LXT_PFQ:
                 case LXT_MBUF:
@@ -246,7 +262,7 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
                         return 0;
                     }
 
-                    break;      /* LXT_CPU/IF/IO/IO1/MEM/PF/MBUF/DEBUG/PROC */
+                    break;      /* LXT_CPU/IF/IF1/IO/IO1/MEM/MEM1/PF/MBUF/DEBUG/PROC */
                 case LXT_COMMA:
                     break;
                 default:
@@ -340,9 +356,11 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
             case LXT_CPU:
             case LXT_DF:
             case LXT_IF:
+            case LXT_IF1:
             case LXT_IO:
             case LXT_IO1:
             case LXT_MEM:
+            case LXT_MEM1:
             case LXT_PF:
             case LXT_PFQ:
             case LXT_MBUF:
@@ -408,7 +426,7 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
                         stream->file = xstrdup(l->token);
                     }
                 }
-                break;          /* LXT_CPU/IF/IO/IO1/MEM/PF/PFQ/MBUF/DEBUG/PROC/SENSOR */
+                break;          /* LXT_CPU/IF/IF1/IO/IO1/MEM/MEM1/PF/PFQ/MBUF/DEBUG/PROC/SENSOR */
             default:
                 parse_error(l, "{cpu|if|io|mem|pf|mbuf|debug|proc|sensor}");
                 return 0;
